# MikuBot

Bot used for the Eden Project discord server.

## Prerequisites

* Python 3.11 or above

## Usage

### Windows

1. Create a `token.txt` which contains the bot's token.
1. Copy the `settings.json.template` and rename it to `settings.json` and fill it out with the necessary data.
1. run the `run.cmd`.

_Note: Make sure `py` starts a Python interpreter or change the `run.cmd` to use `python` instead._

## Acknowledgements

* [Bot Avatar](https://cdn.discordapp.com/app-icons/1078530934766321744/65ae221617e928f3ff928e535885d66d.png?size=256)
